.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
  #
  # THIS IS A GENERATED FILE -- DO NOT EDIT!
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. index:: references

.. _chap_references:

**********
References
**********

This list aims to be a collection of literature, that is of particular interest
in the context of multivariate pattern analysis. It includes all references
cited throughout this manual, but also a number of additional manuscripts
containing descriptions of interesting analysis methods or fruitful
experiments.


.. _AHL+13:

**Adluru, N., Hanlon, B. M., Lutz, A., Lainhart, J. E., Alexander, A. L. & Davidson, R. J.** (2013). Penalized Likelihood Phenotyping: Unifying Voxelwise Analyses and Multi-Voxel Pattern Analyses in Neuroimaging. *Neuroinformatics*, 1-21.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1007/s12021-012-9175-9


.. _AVM+12:

**Albanese, D., Visintainer, R., Merler, S., Riccadonna, S., Jurman, G. & Furlanello, C.** (2012). mlpy: machine learning Python. *arXiv preprint arXiv:1202.6548*.
  Keywords: :keyword:`pymvpa-reference`


.. _ARV+13:

**Andersson, P., Ramsey, N. F., Viergever, M. A. & Pluim, J. P.** (2013). 7T fMRI reveals feasibility of covert visual attention-based brain–computer interfacing with signals obtained solely from cortical grey matter accessible by subdural surface electrodes. *Clinical neurophysiology*, *124*, 2191-2197.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1016/j.clinph.2013.05.009


.. _ALR+14:

**Avants, B. B., Libon, D. J., Rascovsky, K., Boller, A., McMillan, C. T., Massimo, L., Coslett, H. B., Chatterjee, A., Gross, R. G. & Grossman, M.** (2014). Sparse canonical correlation analysis relates network-level atrophy to multivariate cognitive measures in a neurodegenerative population. *NeuroImage*, *84*, 698-711.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2013.09.048

  URL: http://dx.doi.org/10.1016/j.neuroimage.2013.09.048


.. _Ban09:

**Bandettini, P. A.** (2009). Seven topics in functional magnetic resonance imaging. *Journal of Integrative Neuroscience*, *8*, 371–403.
  Keywords: :keyword:`pymvpa-reference`

  URL: http://www.ncbi.nlm.nih.gov/pubmed/19938211


.. _BHG+13:

**Baumgartner, F., Hanke, M., Geringswald, F., Zinke, W., Speck, O. & Pollmann, S.** (2013). Evidence for feature binding in the superior parietal lobule. *NeuroImage*, *68*, 173-180.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2012.12.002


.. _CCK+11:

**Carlin, J. D., Calder, A. J., Kriegeskorte, N., Nili, H. & Rowe, J. B.** (2011). A head view-invariant representation of gaze direction in anterior superior temporal sulcus. *Curr Biol*, *21*, 1817–21.
  DOI: http://dx.doi.org/10.1016/j.cub.2011.09.025


.. _CRK+11:

**Carlin, J. D., Rowe, J. B., Kriegeskorte, N., Thompson, R. & Calder, A. J.** (2011). Direction-Sensitive Codes for Observed Head Turns in Human Superior Temporal Sulcus. *Cerebral Cortex*, **, .
  Keywords: :keyword:`pymvpa`, :keyword:`fMRI`, :keyword:`searchlight`

  DOI: http://dx.doi.org/10.1093/cercor/bhr061

  URL: http://cercor.oxfordjournals.org/content/early/2011/06/27/cercor.bhr061.short


.. _CBR+12:

**Carter, R. M., Bowling, D. L., Reeck, C. & Huettel, S. A.** (2012). A distinct role of the temporal-parietal junction in predicting socially guided decisions. *Science*, *337*, 109-111.
  DOI: http://dx.doi.org/10.1126/science.1219681


.. _CPL+06:

**Chen, X., Pereira, F., Lee, W., Strother, S. & Mitchell, T.** (2006). Exploring predictive and reproducible modeling with the single-subject FIAC dataset. *Human Brain Mapping*, *27*, 452–461.
  *This paper illustrates the necessity to consider the stability or
  reproducibility of a classifier's feature selection as at least equally
  important to it's generalization performance.*

  Keywords: :keyword:`feature selection`, :keyword:`feature selection stability`

  DOI: http://dx.doi.org/10.1002/hbm.20243

  URL: http://eutils.ncbi.nlm.nih.gov/entrez/eutils/elink.fcgi?cmd=prlinks&dbfrom=pubmed&retmode=ref&id=16565951


.. _CSM+10:

**Clithero, J. A., Smith, D. V., Carter, R. M. & Huettel, S. A.** (2010). Within- and cross-participant classifiers reveal different neural coding of information. *NeuroImage*.
  DOI: http://dx.doi.org/10.1016/j.neuroimage.2010.03.057

  URL: http://www.ncbi.nlm.nih.gov/pubmed/20347995


.. _Coh94:

**Cohen, J.** (1994). The earth is round (p< 0.05). *American Psychologist*, *49*, 997–1003.
  *Classical critic of null hypothesis significance testing*

  Keywords: :keyword:`hypothesis testing`

  URL: http://www.citeulike.org/user/mdreid/article/2643653


.. _CAS+10:

**Cohen, J. R., Asarnow, R. F., Sabb, F. W., Bilder, R. M., Bookheimer, S. Y., Knowlton, B. J. & Poldrack, R. A.** (2010). Decoding developmental differences and individual variability in response inhibition through predictive analyses across individuals. *Frontiers in Human Neuroscience*, *4:47*.
  DOI: http://dx.doi.org/10.3389/fnhum.2010.00047

  URL: http://www.ncbi.nlm.nih.gov/pubmed/20661296


.. _CEZ+11:

**Cole, M. W., Etzel, J. A., Zacks, J. M., Schneider, W. & Braver, T. S.** (2011). Rapid transfer of abstract rules to novel contexts in human lateral prefrontal cortex. *Frontiers in Human Neuroscience*, *5*.
  DOI: http://dx.doi.org/10.3389/fnhum.2011.00142


.. _CIB15:

**Cole, M. W., Ito, T. & Braver, T. S.** (2015). The Behavioral Relevance of Task Information in Human Prefrontal Cortex. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1093/cercor/bhv072

  URL: http://dx.doi.org/10.1093/cercor/bhv072


.. _CGG+12:

**Connolly, A. C., Guntupalli, J. S., Gors, J., Hanke, M., Halchenko, Y. O., Wu, Y., Abdi, H. & Haxby, J. V.** (2012). The Representation of Biological Classes in the Human Brain. *Journal of Neuroscience*, *32*, 2608-2618.
  DOI: http://dx.doi.org/10.1523/JNEUROSCI.5547-11.2012

  URL: http://www.jneurosci.org/content/32/8/2608#aff-4


.. _Dem06:

**Demšar, J.** (2006). Statistical Comparisons of Classifiers over Multiple Data Sets. *Journal of Machine Learning Research*, *7*, 1–30.
  *This is a review of several classifier benchmark procedures.*

  URL: http://portal.acm.org/citation.cfm?id=1248548


.. _DTM+11:

**Duff, E. P., Trachtenberg, A. J., CE, C. E. M., Howard, M. A., Wilson, F., Smith, S. M. & Woolrich, M. W.** (2011). Task-driven ICA feature generation for accurate and interpretable prediction using fMRI. *NeuroImage*, *60*, 189-203.
  URL: http://www.ncbi.nlm.nih.gov/pubmed/22227050


.. _EHJ+04:

**Efron, B., Trevor, H., Johnstone, I. & Tibshirani, R.** (2004). Least Angle Regression. *Annals of Statistics*, *32*, 407–499.
  Keywords: :keyword:`least angle regression`, :keyword:`LARS`

  DOI: http://dx.doi.org/10.1214/009053604000000067


.. _EDT+12:

**Ekman, M., Derrfuss, J., Tittgemeyer, M. & Fiebach, C. J.** (2012). Predicting errors from reconfiguration patterns in human brain networks. *Proceedings of the National Academy of Sciences*, *109*, 16714-16719.
  DOI: http://dx.doi.org/10.1073/pnas.1207523109


.. _FWJ+12:

**Farrell, D., Webb, H., Johnston, M. A., Poulsen, T. A., O’Meara, F., Christensen, L. L., Beier, L., Borchert, T. V. & Nielsen, J. E.** (2012). Toward Fast Determination of Protein Stability Maps: Experimental and Theoretical Analysis of Mutants of a Nocardiopsis prasina Serine Protease. *Biochemistry*, *51*, 5339-5347.
  DOI: http://dx.doi.org/10.1021/bi201926f


.. _Fis25:

**Fisher, R. A.** (1925). Statistical methods for research workers. Oliver and Boyd: Edinburgh.
  *One of the 20th century's most influential books on statistical methods, which
  coined the term 'Test of significance'.*

  Keywords: :keyword:`statistics`, :keyword:`hypothesis testing`

  URL: http://psychclassics.yorku.ca/Fisher/Methods/


.. _FKM+14:

**Fogelson, S. V., Kohler, P. J., Miller, K. J., Granger, R. & Tse, P. U.** (2014). Unconscious neural processing differs with method used to render stimuli invisible. *Frontiers in Psychology*, *5*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.3389/fpsyg.2014.00601

  URL: http://dx.doi.org/10.3389/fpsyg.2014.00601


.. _GF09:

**Garcia, S. & Fourcaud-Trocmé, N.** (2009). OpenElectrophy: An Electrophysiological Data- and Analysis-Sharing Framework. *Front Neuroinformatics*, *3*, 14.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.3389/neuro.11.014.2009

  URL: http://www.ncbi.nlm.nih.gov/pubmed/19521545


.. _GWC10:

**Gilliam, T., Wilson, R. C. & Clark, J. A.** (2010). Scribe Identification in Medieval English Manuscripts.  Proceedings of the International Conference on Pattern Recognition.
  URL: ftp://ftp.computer.org/press/outgoing/proceedings/juan/icpr10b/data/4109b880.pdf


.. _GMS+12:

**Gorlin, S., Meng, M., Sharma, J., Sugihara, H., Sur, M. & Sinha, P.** (2012). Imaging prior information in the brain. *Proceedings of the National Academy of Sciences*, *109*, 7935-7940.
  DOI: http://dx.doi.org/10.1073/pnas.1111224109

  URL: http://www.pnas.org/content/109/20/7935.abstract


.. _GSD+15:

**Greisel, N., Seitz, S., Drory, N., Bender, R., Saglia, R. & Snigula, J.** (2015). Photometric Redshifts and Model Spectral Energy Distributions of Galaxies From the SDSS-III BOSS DR10 Data. *arXiv preprint arXiv:1505.01157*.
  Keywords: :keyword:`pymvpa`

  URL: http://arxiv.org/abs/1505.01157


.. _GHH+16:

**Guntupalli, J. S., Hanke, M., Halchenko, Y. O., Connolly, A. C., Ramadge, P. J. & Haxby, J. V.** (2016). A Model of Representational Spaces in Human Cortex. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`, :keyword:`hyperalignment`

  DOI: http://dx.doi.org/10.1093/cercor/bhw068


.. _GM15:

**Guo, B. & Meng, M.** (2015). The encoding of category-specific versus nonspecific information in human inferior temporal cortex. *NeuroImage*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2015.04.006

  URL: http://dx.doi.org/10.1016/j.neuroimage.2015.04.006


.. _GE03:

**Guyon, I. & Elisseeff, A.** (2003). An Introduction to Variable and Feature Selection. *Journal of Machine Learning*, *3*, 1157–1182.
  URL: http://www.jmlr.org/papers/v3/guyon03a.html


.. _HBI+14:

**Hanke, M., Baumgartner, F. J., Ibe, P., Kaule, F. R., Pollmann, S., Speck, O., Zinke, W. & Stadler, J.** (in press). A high-resolution 7-Tesla fMRI dataset from complex natural stimulation with an audio movie. *Scientific Data*.
  Keywords: :keyword:`pymvpa`

  URL: http://www.studyforrest.org


.. _HHH+10:

**Hanke, M., Halchenko, Y. O., Haxby, J. V. & Pollmann, S.** (2010). Statistical learning analysis in neuroscience: aiming for transparency. *Frontiers in Neuroscience*, *4*, 38–43.
  *Focused review article emphasizing the role of transparency to facilitate
  adoption and evaluation of statistical learning techniques in neuroimaging
  research.*

  DOI: http://dx.doi.org/10.3389/neuro.01.007.2010


.. _HHS+latest:

**Hanke, M., Halchenko, Y. O., Sederberg, P. B. & Hughes, J. M.** The PyMVPA Manual. Available online at http://www.pymvpa.org/PyMVPA-Manual.pdf.

.. _HHS+09a:

**Hanke, M., Halchenko, Y. O., Sederberg, P. B., Hanson, S. J., Haxby, J. V. & Pollmann, S.** (2009). PyMVPA: A Python toolbox for multivariate pattern analysis of fMRI data. *Neuroinformatics*, *7*, 37–53.
  *Introduction into the analysis of fMRI data using PyMVPA.*

  Keywords: :keyword:`PyMVPA`, :keyword:`fMRI`

  DOI: http://dx.doi.org/10.1007/s12021-008-9041-y


.. _HHS+09b:

**Hanke, M., Halchenko, Y. O., Sederberg, P. B., Olivetti, E., Fründ, I., Rieger, J. W., Herrmann, C. S., Haxby, J. V., Hanson, S. J. & Pollmann, S.** (2009). PyMVPA: A Unifying Approach to the Analysis of Neuroscientific Data. *Frontiers in Neuroinformatics*, *3*, 3.
  *Demonstration of PyMVPA capabilities concerning multi-modal or
  modality-agnostic data analysis.*

  Keywords: :keyword:`PyMVPA`, :keyword:`fMRI`, :keyword:`EEG`, :keyword:`MEG`, :keyword:`extracellular recordings`

  DOI: http://dx.doi.org/10.3389/neuro.11.003.2009


.. _HH08:

**Hanson, S. J. & Halchenko, Y. O.** (2008). Brain reading using full brain support vector machines for object recognition: there is no "face" identification area. *Neural Computation*, *20*, 486–503.
  Keywords: :keyword:`support vector machine`, :keyword:`SVM`, :keyword:`feature selection`, :keyword:`recursive feature elimination`, :keyword:`RFE`

  DOI: http://dx.doi.org/10.1162/neco.2007.09-06-340


.. _HS11:

**Hanson, S. J. & Schmidt, A.** (2011). High-resolution imaging of the fusiform face area (FFA) using multivariate non-linear classifiers shows diagnosticity for non-face categories. *NeuroImage*, *54*, 1715-1734.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2010.08.02


.. _HMH04:

**Hanson, S. J., Matsuka, T. & Haxby, J. V.** (2004). Combinatorial codes in ventral temporal lobe for object recognition: Haxby (2001) revisited: is there a "face" area?. *NeuroImage*, *23*, 156–166.
  DOI: http://dx.doi.org/10.1016/j.neuroimage.2004.05.020


.. _HSN+13:

**Hassabis, D., Spreng, R. N., Rusu, A. A., Robbins, C. A., Mar, R. A. & Schacter, D. L.** (2013). Imagine all the people: How the brain creates and uses personality models to predict behavior. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1093/cercor/bht042


.. _HTF09:

**Hastie, T., Tibshirani, R. & Friedman, J. H.** (2009). The Elements of Statistical Learning: Data Mining, Inference, and Prediction. Springer: New York.
  *Excellent summary of virtually all techniques relevant to the field. A free PDF
  version of this book is available from the authors' website at
  http://web.stanford.edu/%7Ehastie/ElemStatLearn/*

  DOI: http://dx.doi.org/10.1007/b94608

  URL: http://web.stanford.edu/%7Ehastie/ElemStatLearn/


.. _HCG14:

**Haxby, J. V., Connolly, A. C. & Guntupalli, J. S.** (2014). Decoding neural representational spaces using multivariate pattern analysis. *Annual review of neuroscience*, *37*, 435-456.
  Keywords: :keyword:`pymvpa-reference`


.. _HGF+01:

**Haxby, J. V., Gobbini, M. I., Furey, M. L., Ishai, A., Schouten, J. L. & Pietrini, P.** (2001). Distributed and overlapping representations of faces and objects in ventral temporal cortex. *Science*, *293*, 2425–2430.
  Keywords: :keyword:`split-correlation classifier`

  DOI: http://dx.doi.org/10.1126/science.1063736


.. _HGC+11:

**Haxby, J. V., Guntupalli, J. S., Connolly, A. C., Halchenko, Y. O., Conroy, B. R., Gobbini, M. I., Hanke, M. & Ramadge, P. J.** (2011). A Common, High-Dimensional Model of the Representational Space in Human Ventral Temporal Cortex. *Neuron*, *72*, 404–416.
  Keywords: :keyword:`pymvpa`, :keyword:`hyperalignment`

  DOI: http://dx.doi.org/10.1016/j.neuron.2011.08.026

  URL: http://www.cell.com/neuron/abstract/S0896-6273%2811%2900781-1


.. _HR06:

**Haynes, J. & Rees, G.** (2006). Decoding mental states from brain activity in humans. *Nature Reviews Neuroscience*, *7*, 523–534.
  *Review of decoding studies, emphasizing the importance of ethical issues
  concerning the privacy of personal thought.*

  DOI: http://dx.doi.org/10.1038/nrn1931


.. _HGH2015:

**Hebart, M. N., Görgen, K. & Haynes, J.** The Decoding Toolbox (TDT): a versatile software package for multivariate analyses of functional imaging data. *Frontiers in Neuroinformatics*, *8*.
  DOI: http://dx.doi.org/10.3389/fninf.2014.00088


.. _HPL+14:

**Heitmeyer, C. L., Pickett, M., Leonard, E. I., Archer, M. M., Ray, I., Aha, D. W. & Trafton, J. G.** (2014). Building high assurance human-centric decision systems. *Autom Softw Eng*, *22*, 159-197.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1007/s10515-014-0157-z

  URL: http://dx.doi.org/10.1007/s10515-014-0157-z


.. _HSC+14:

**Helfinstein, S. M., Schonberg, T., Congdon, E., Karlsgodt, K. H., Mumford, J. A., Sabb, F. W., Cannon, T. D., London, E. D., Bilder, R. M. & Poldrack, R. A.** (2014). Predicting risky choices from brain activity patterns. *Proceedings of the National Academy of Sciences*, *111*, 2470-2475.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1073/pnas.1321728111

  URL: http://www.pnas.org/content/111/7/2470.abstract


.. _HBL+12:

**Hiroyuki, A., Brian, M., Li, N., Yumiko, S. & Massimo, P.** (2012). Decoding Semantics across fMRI sessions with Different Stimulus Modalities: A practical MVPA Study. *Frontiers in Neuroinformatics*, *6*.
  Keywords: :keyword:`pymvpa`, :keyword:`fmri`

  DOI: http://dx.doi.org/10.3389/fninf.2012.00024

  URL: http://www.frontiersin.org/Neuroinformatics/10.3389/fninf.2012.00024/full


.. _HRB+11:

**Hollmann, M., Rieger, J. W., Baecke, S., Lützkendorf, R., Müller, C., Adolf, D. & Bernarding, J.** (2011). Predicting decisions in human social interactions using real-time fMRI and pattern classification. *PloS one*, *6*, e25304.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1371/journal.pone.0025304


.. _HS14:

**Huffman, D. J. & Stark, C. E.** (2014). Multivariate pattern analysis of the human medial temporal lobe revealed representationally categorical cortex and representationally agnostic hippocampus. *Hippocampus*, *24*, 1394-1403.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1002/hipo.22321

  URL: http://dx.doi.org/10.1002/hipo.22321


.. _Ioa05:

**Ioannidis, J. P. A.** (2005). Why most published research findings are false. *PLoS Med*, *2*, e124.
  *Simulation study speculating that it is more likely for a research claim to be
  false than true. Along the way the paper highlights aspects to keep in mind
  while assessing the 'scientific significance' of any given study, such as,
  viability, reproducibility, and results.*

  Keywords: :keyword:`hypothesis testing`

  DOI: http://dx.doi.org/10.1371/journal.pmed.0020124


.. _JK12:

**Jain, A. & Kemp, C. C.** (2012). Improving robot manipulation with data-driven object-centric models of everyday forces. *Autonomous Robots*, 1-17.
  DOI: http://dx.doi.org/10.1007/s10514-013-9344-1

  URL: http://www.hrl.gatech.edu/pdf/improve_everyday_forces.pdf


.. _JP11:

**Jimura, K. & Poldrack, R.** (2011). Analyses of regional-average activation and multivoxel pattern information tell complementary stories. *Neuropsychologia*.
  DOI: http://dx.doi.org/10.1016/j.neuropsychologia.2011.11.007


.. _JCS+14:

**Jimura, K., Cazalis, F., Stover, E. R. S. & Poldrack, R. A.** (2014). The neural basis of task switching changes with skill acquisition. *Front. Hum. Neurosci.*, *8*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.3389/fnhum.2014.00339

  URL: http://dx.doi.org/10.3389/fnhum.2014.00339


.. _JL09:

**Jurica, P. & van Leeuwen, C.** (2009). OMPC: an open-source MATLAB-to-Python compiler. *Frontiers in Neuroinformatics*, *3*, 5.
  DOI: http://dx.doi.org/10.3389/neuro.11.005.2009


.. _JSW09:

**Jäkel, F., Schölkopf, B. & Wichmann, F. A.** (2009). Does Cognitive Science Need Kernels?. *Trends in Cognitive Sciences*, *13*, 381–388.
  *A summary of the relationship of machine learning and cognitive science.
  Moreover it also points out the role of kernel-based methods in this context.*

  Keywords: :keyword:`kernel methods`, :keyword:`similarity`

  DOI: http://dx.doi.org/10.1016/j.tics.2009.06.002

  URL: http://www.sciencedirect.com/science/article/B6VH9-4X4R9BC-1/2/e2e90008d0a8887878c72777462335fd


.. _KT05:

**Kamitani, Y. & Tong, F.** (2005). Decoding the visual and subjective contents of the human brain. *Nature Neuroscience*, *8*, 679–685.
  *One of the two studies showing the possibility to read out orientation
  information from visual cortex.*

  DOI: http://dx.doi.org/10.1038/nn1444


.. _KM12:

**Kaplan, J. T. & Meyer, K.** (2012). Multivariate pattern analysis reveals common neural patterns across individuals during touch observation. *Neuroimage*, *60*, 204-212.
  DOI: http://dx.doi.org/10.1016/j.neuroimage.2011.12.059


.. _Kas14:

**Kasabov, N. K.** (2014). NeuCube: A spiking neural network architecture for mapping, learning and understanding of spatio-temporal brain data. *Neural Networks*, *52*, 62-76.
  DOI: http://dx.doi.org/10.1016/j.neunet.2014.01.006

  URL: http://dx.doi.org/10.1016/j.neunet.2014.01.006


.. _KKO+11:

**Kaunitz, L. N., Kamienkowski, J. E., Olivetti, E., Murphy, B., Avesani, P. & Melcher, D. P.** (2011). Intercepting the first pass: rapid categorization is suppressed for unseen stimuli. *Frontiers in Perception Science*, *2*, 198.
  Keywords: :keyword:`pymvpa`, :keyword:`eeg`

  DOI: http://dx.doi.org/10.3389/fpsyg.2011.00198

  URL: http://www.frontiersin.org/perception_science/10.3389/fpsyg.2011.00198/full


.. _KFS+09:

**Kienzle, W., Franz, M. O., Schölkopf, B. & Wichmann, F. A.** (In press). Center-surround patterns emerge as optimal predictors for human saccade targets. *Journal of Vision*.
  *This paper offers an approach to make sense out of feature sensitivities of
  non-linear classifiers.*


.. _KLE+14:

**Kim, N. Y., Lee, S. M., Erlendsdottir, M. C. & McCarthy, G.** (2014). Discriminable spatial patterns of activation for faces and bodies in the fusiform gyrus. *Front. Hum. Neurosci.*, *8*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.3389/fnhum.2014.00632

  URL: http://dx.doi.org/10.3389/fnhum.2014.00632


.. _KZ14:

**Klein, M. E. & Zatorre, R. J.** (2014). Representations of Invariant Musical Categories Are Decodable by Pattern Analysis of Locally Distributed BOLD Responses in Superior Temporal and Intraparietal Sulci. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1093/cercor/bhu003

  URL: http://dx.doi.org/10.1093/cercor/bhu003


.. _KFR+13:

**Kohler, P. J., Fogelson, S. V., Reavis, E. A., Meng, M., Guntupalli, J. S., Hanke, M., Halchenko, Y. O., Connolly, A. C., Haxby, J. V. & Tse, P. U.** (2013). Pattern classification precedes region-average hemodynamic response in early visual cortex. *NeuroImage*, *78*, 249-260.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2013.04.019


.. _KGB06:

**Kriegeskorte, N., Goebel, R. & Bandettini, P. A.** (2006). Information-based functional brain mapping. *Proceedings of the National Academy of Sciences of the USA*, *103*, 3863–3868.
  *Paper introducing the searchlight algorithm.*

  Keywords: :keyword:`searchlight`

  DOI: http://dx.doi.org/10.1073/pnas.0600244103


.. _KMB08:

**Kriegeskorte, N., Mur, M. & Bandettini, P. A.** (2008). Representational similarity analysis - connecting the branches of systems neuroscience. *Frontiers in Systems Neuroscience*, *2*, 4.
  DOI: http://dx.doi.org/10.3389/neuro.06.004.2008


.. _KCF+05:

**Krishnapuram, B., Carin, L., Figueiredo, M. A. & Hartemink, A. J.** (2005). Sparse multinomial logistic regression: fast algorithms and generalization bounds. *IEEE Transactions on Pattern Analysis and Machine Intelligence*, *27*, 957–968.
  Keywords: :keyword:`sparse multinomial logistic regression`, :keyword:`SMLR`

  DOI: http://dx.doi.org/10.1109/TPAMI.2005.127

  URL: http://eutils.ncbi.nlm.nih.gov/entrez/eutils/elink.fcgi?cmd=prlinks&dbfrom=pubmed&retmode=ref&id=15943426


.. _KWO11:

**Kubilius, J., Wagemans, J. & Beeck, H. O. d.** (2011). Emergence of perceptual gestalts in the human visual cortex: The case of the configural superiority effect. *Psychological Science*, *in press*.
  Keywords: :keyword:`pymvpa`, :keyword:`fMRI`

  DOI: http://dx.doi.org/10.1177/0956797611417000


.. _KWO14:

**Kubilius, J., Wagemans, J. & Beeck, H. P. O. d.** (2014). Encoding of configural regularity in the human visual system. *Journal of Vision*, *14*, 11-11.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1167/14.9.11

  URL: http://dx.doi.org/10.1167/14.9.11


.. _LSC+05:

**LaConte, S., Strother, S., Cherkassky, V., Anderson, J. & Hu, X.** (2005). Support vector machines for temporal classification of block design fMRI data. *NeuroImage*, *26*, 317–329.
  *Comprehensive evaluation of preprocessing options with respect to
  SVM-classifier (and others) performance on block-design fMRI data.*

  Keywords: :keyword:`SVM`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2005.01.048


.. _LaC10:

**Laconte, S. M.** (2010). Decoding fMRI brain states in real-time. *NeuroImage*.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2010.06.052

  URL: http://www.ncbi.nlm.nih.gov/pubmed/20600972


.. _LBB+98:

**Lecun, Y., Bottou, L., Bengio, Y. & Haffner, P.** (1998). Gradient-based learning applied to document recognition. *Proceedings of the IEEE*, *86*, 2278–2324.
  *Paper introducing Modified NIST (MNIST) dataset for performance comparisons of
  character recognition performance across a variety of classifiers.*

  Keywords: :keyword:`handwritten character recognition`, :keyword:`multilayer neural networks`, :keyword:`MNIST`, :keyword:`statistical learning`

  DOI: http://dx.doi.org/10.1109/5.726791


.. _LMcC14:

**Lee, S. M. & McCarthy, G.** (2014). Functional Heterogeneity and Convergence in the Right Temporoparietal Junction. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1093/cercor/bhu292

  URL: http://dx.doi.org/10.1093/cercor/bhu292


.. _LB10:

**Legge, D. & Badii, A.** (2010). An Application of Pattern Matching for the Adjustment of Quality of Service Metrics. The International Conference on Emerging Network Intelligence.
  Keywords: :keyword:`pymvpa-reference`


.. _LB13:

**Lescroart, M. D. & Biederman, I.** (2013). Cortical representation of medial axis structure. *Cerebral Cortex*, *23*, 629-637.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1093/cercor/bhs046


.. _LMH+13:

**Liang, M., Mouraux, A., Hu, L. & Iannetti, G.** (2013). Primary sensory cortices contain distinguishable spatial patterns of activity for each sense. *Nature communications*, *4*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1038/ncomms2979


.. _KKD+12:

**Man, K., Kaplan, J. T., Damasio, A. & Meyer, K.** (2012). Sight and sound converge to form modality-invariant representations in temporoparietal cortex. *The Journal of Neuroscience*, *32*, 16629-16636.
  DOI: http://dx.doi.org/10.1523/JNEUROSCI.2342-12.2012


.. _MR13:

**Manelis, A. & Reder, L. M.** (2013). He Who Is Well Prepared Has Half Won The Battle: An fMRI Study of Task Preparation. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1093/cercor/bht262

  URL: http://cercor.oxfordjournals.org/content/early/2013/10/02/cercor.bht262.abstract


.. _MHH10:

**Manelis, A., Hanson, C. & Hanson, S. J.** (2010). Implicit memory for object locations depends on reactivation of encoding-related brain regions. *Human Brain Mapping*.
  Keywords: :keyword:`pymvpa`, :keyword:`implicit memory`, :keyword:`fMRI`

  DOI: http://dx.doi.org/10.1002/hbm.20992


.. _MRH11:

**Manelis, A., Reder, L. M. & Hanson, S. J.** (2011). Dynamic Changes In The Medial Temporal Lobe During Incidental Learning Of Object–Location Associations. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`, :keyword:`fMRI`

  DOI: http://dx.doi.org/10.1093/cercor/bhr151


.. _MBL+10:

**Margulies, D. S., Böttger, J., Long, X., Lv, Y., Kelly, C., Schäfer, A., Goldhahn, D., Abbushi, A., Milham, M. P., Lohmann, G. & Villringer, A.** (2010). Resting developments: a review of fMRI post-processing methodologies for spontaneous brain activity. *Magnetic Resonance Materials in Physics, Biology and Medicine*, *23*, 289–307.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1007/s10334-010-0228-5

  URL: http://www.ncbi.nlm.nih.gov/pubmed/20972883


.. _McMLZ+15:

**McNamee, D., Liljeholm, M., Zika, O. & O'Doherty, J. P.** (2015). Characterizing the Associative Content of Brain Structures Involved in Habitual and Goal-Directed Actions in Humans: A Multivariate fMRI Study. *The Journal of Neuroscience*, *35*, 3764-3771.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1523/JNEUROSCI.4677-14.2015


.. _MRO13:

**McNamee, D., Rangel, A. & O'Doherty, J. P.** (2013). Category-dependent and category-independent goal-value codes in human ventromedial prefrontal cortex. *Nature neuroscience*, *16*, 479-485.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1038/nn.3337


.. _MSB+12:

**Merrill, J., Sammler, D., Bangert, M., Goldhahn, D., Lohmann, G., Turner, R. & Friederici, A. D.** (2012). Perception of words and pitch patterns in song and speech. *Frontiers in psychology*, *3*, 76.
  DOI: http://dx.doi.org/10.3389/fpsyg.2012.000


.. _MK11:

**Meyer, K. & Kaplan, J. T.** (2011). Cross-Modal Multivariate Pattern Analysis. *Journal of visualized experiments: JoVE*.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.3791/3307


.. _MKE+11:

**Meyer, K., Kaplan, J. T., Essex, R., Damasio, H. & Damasio, A.** (2011). Seeing Touch Is Correlated with Content-Specific Activity in Primary Somatosensory Cortex. *Cerebral Cortex*.
  DOI: http://dx.doi.org/10.1093/cercor/bhq289

  URL: http://www.ncbi.nlm.nih.gov/pubmed/21330469


.. _MKE10:

**Meyer, K., Kaplan, J. T., Essex, R., Webber, C., Damasio, H. & Damasio, A.** (2010). Predicting visual stimuli based on activity in auditory cortices. *Nature Neuroscience*.
  DOI: http://dx.doi.org/10.1038/nn.2533


.. _MHN+04:

**Mitchell, T., Hutchinson, R., Niculescu, R. S., Pereira, F., Wang, X., Just, M. & Newman, S.** (2004). Learning to Decode Cognitive States from Brain Images. *Machine Learning*, *57*, 145–175.
  DOI: http://dx.doi.org/10.1023/B:MACH.0000035475.85309.1b


.. _MBT+14:

**Mittner, M., Boekel, W., Tucker, A. M., Turner, B. M., Heathcote, A. & Forstmann, B. U.** (2014). When the Brain Takes a Break: A Model-Based Analysis of Mind Wandering. *Journal of Neuroscience*, *34*, 16286-16295.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1523/jneurosci.2062-14.2014

  URL: http://dx.doi.org/10.1523/JNEUROSCI.2062-14.2014


.. _MBK09:

**Mur, M., Bandettini, P. A. & Kriegeskorte, N.** (2009). Revealing representational content with pattern-information fMRI–an introductory guide. *Social Cognitive and Affective Neuroscience*.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1093/scan/nsn044


.. _NH02:

**Nichols, T. E. & Holmes, A. P.** (2002). Nonparametric permutation tests for functional neuroimaging: a primer with examples. *Human Brain Mapping*, *15*, 1–25.
  *Overview of standard nonparametric randomization and permutation testing
  applied to neuroimaging data (e.g. fMRI)*

  DOI: http://dx.doi.org/10.1002/hbm.1058


.. _NPD+06:

**Norman, K. A., Polyn, S. M., Detre, G. J. & Haxby, J. V.** (2006). Beyond mind-reading: multi-voxel pattern analysis of fMRI data. *Trends in Cognitive Science*, *10*, 424–430.
  DOI: http://dx.doi.org/10.1016/j.tics.2006.07.005


.. _OJA+05:

**O'Toole, A. J., Jiang, F., Abdi, H. & Haxby, J. V.** (2005). Partially Distributed Representations of Objects and Faces in Ventral Temporal Cortex . *Journal of Cognitive Neuroscience*, *17*, 580–590.
  DOI: http://dx.doi.org/10.1162/0898929053467550


.. _OJA+07:

**O'Toole, A. J., Jiang, F., Abdi, H., Penard, N., Dunlop, J. P. & Parent, M. A.** (2007). Theoretical, statistical, and practical perspectives on pattern-based classification approaches to the analysis of functional neuroimaging data. *Journal of Cognitive Neuroscience*, *19*, 1735–1752.
  DOI: http://dx.doi.org/10.1162/jocn.2007.19.11.1735


.. _OGA2012:

**Olivetti, E., Greiner, S. & Avesani, P.** (2012). Induction in Neuroscience with Classification: Issues and Solutions. Machine Learning and Interpretation in Neuroimaging, 42-50.
  DOI: http://dx.doi.org/10.1007/978-3-642-34713-9_6


.. _OVG+10:

**Olivetti, E., Veeramachaneni, S., Greiner, S. & Avesani, P.** (2010). Brain Connectivity Analysis by Reduction to Pair Classification. The 2nd IAPR International Workshop on Cognitive Information Processing.

.. _OWD+11:

**Oosterhof, N. N., Wiestler, T., Downing, P. E. & Diedrichsen, J.** (2011). A comparison of volume-based and surface-based multi-voxel pattern analysis. *NeuroImage*, *56*, 593-600.

.. _PLW14:

**Parkinson, C., Liu, S. & Wheatley, T.** (2014). A Common Cortical Metric for Spatial, Temporal, and Social Distance. *Journal of Neuroscience*, *34*, 1979-1987.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1523/jneurosci.2159-13.2014

  URL: http://dx.doi.org/10.1523/JNEUROSCI.2159-13.2014


.. _PVG+11:

**Pedregosa, F., Varoquaux, G., Gramfort, A., Michel, V., Thirion, B., Grisel, O., Blondel, M., Prettenhofer, P., Weiss, R., Dubourg, V., Vanderplas, J., Passos, A., Cournapeau, D., Brucher, M., Perrot, M. & Duchesnay, E.** (2011). Scikit-learn: Machine Learning in Python. *Journal of Machine Learning Research*, *12*, 2825-2830.
  Keywords: :keyword:`pymvpa-reference`

  URL: http://dl.acm.org/citation.cfm?id=1953048.2078195


.. _PB11:

**Pereira, F. & Botvinick, M.** (2011). Information mapping with pattern classifiers: a comparative study. *Neuroimage*, *56*, 476-496.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2010.05.026


.. _PMB09:

**Pereira, F., Mitchell, T. & Botvinick, M.** (2009). Machine learning classifiers and fMRI: A tutorial overview. *NeuroImage*, *45*, 199–209.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2008.11.007

  URL: http://www.ncbi.nlm.nih.gov/pmc/articles/PMC2892746/


.. _PSR11:

**Pernet, C. R., Sajda, P. & Rousselet, G. A.** (2011). Single-trial analyses: why bother?. *Front Psychol*, *2*, 322.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.3389/fpsyg.2011.00322


.. _PP07:

**Pessoa, L. & Padmala, S.** (2007). Decoding near-threshold perception of fear from distributed single-trial brain activation. *Cerebral Cortex*, *17*, 691–701.
  *Analysis of slow event-related fMRI data using patter classification techniques.*

  DOI: http://dx.doi.org/10.1093/cercor/bhk020


.. _PSE14:

**Plitt, M., Savjani, R. R. & Eagleman, D. M.** (2014). Are corporations people too? The neural correlates of moral judgments about companies and individuals. *Social Neuroscience*, *10*, 113-125.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1080/17470919.2014.978026

  URL: http://dx.doi.org/10.1080/17470919.2014.978026


.. _PZB+14:

**Pollmann, S., Zinke, W., Baumgartner, F., Geringswald, F. & Hanke, M.** (2014). The right temporo-parietal junction contributes to visual feature binding. *NeuroImage*, *101*, 289-297.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2014.07.021

  URL: http://dx.doi.org/10.1016/j.neuroimage.2014.07.021


.. _RC12:

**Raizada, R. D. & Connolly, A. C.** (2012). What makes different people's representations alike: neural similarity-space solves the problem of across-subject fMRI decoding. *Journal of Cognitive Neuroscience*, *24*, 868-877.
  URL: http://raizadalab.org/publications.html


.. _REA+14:

**Rueschemeyer, S., Ekman, M., van Ackeren, M. & Kilner, J.** (2014). Observing, Performing, and Understanding Actions: Revisiting the Role of Cortical Motor Areas in Processing of Action Words. *Journal of Cognitive Neuroscience*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1162/jocn_a_00576


.. _SMM+08:

**Sato, J. R., Mourão-Miranda, J., Martin, M. d. G. M., Amaro, E., Morettin, P. A. & Brammer, M. J.** (2008). The impact of functional connectivity changes on support vector machines mapping of fMRI data. *Journal of Neuroscience Methods*, *172*, 94–104.
  *Discussion of possible scenarios where univariate and multivariate (SVM)
  sensitivity maps derived from the same dataset could differ. Including the
  case were univariate methods would assign a substantially larger score to
  some features.*

  Keywords: :keyword:`support vector machine`, :keyword:`SVM`, :keyword:`sensitivity`

  DOI: http://dx.doi.org/10.1016/j.jneumeth.2008.04.008


.. _SAF+15:

**Schlegel, A., Alexander, P., Fogelson, S. V., Li, X., Lu, Z., Kohler, P. J., Riley, E., Tse, P. U. & Meng, M.** (2015). The artist emerges: Visual art learning alters neural structure and function. *NeuroImage*, *105*, 440-451.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2014.11.014

  URL: http://dx.doi.org/10.1016/j.neuroimage.2014.11.014


.. _SP14:

**Schlichting, M. L. & Preston, A. R.** (2014). Memory reactivation during rest supports upcoming learning of related content. *Proceedings of the National Academy of Sciences*, *111*, 15845-15850.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1073/pnas.1404396111

  URL: http://dx.doi.org/10.1073/pnas.1404396111


.. _SS01:

**Scholkopf, B. & Smola, A.** (2001). Learning with Kernels: Support Vector Machines, Regularization. MIT Press: Cambridge, MA.
  *Good coverage of kernel methods and associated statistical learning aspects
  (e.g. error bounds)*

  Keywords: :keyword:`statistical learning`, :keyword:`kernel methods`, :keyword:`error estimation`


.. _SRR+13:

**Schrouff, J., Rosa, M. J., Rondina, J., Marquand, A., Chu, C., Ashburner, J., Phillips, C., Richiardi, J. & Mourão-Miranda, J.** (2013). PRoNTo: Pattern Recognition for Neuroimaging Toolbox. *Neuroinformatics*, 1-19.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1007/s12021-013-9178-1


.. _SDV+14:

**Schönwiesner, M., Dechent, P., Voit, D., Petkov, C. I. & Krumbholz, K.** (2014). Parcellation of Human and Monkey Core Auditory Cortex with fMRI Pattern Classification and Objective Detection of Tonotopic Gradient Reversals. *Cerebral Cortex*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1093/cercor/bhu124

  URL: http://dx.doi.org/10.1093/cercor/bhu124


.. _SHA+14:

**Sha, L., Haxby, J. V., Abdi, H., Guntupalli, J. S., Oosterhof, N. N., Halchenko, Y. O. & Connolly, A. C.** (2014). The Animacy Continuum in the Human Ventral Vision Pathway. *Journal of Cognitive Neuroscience*.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1162/jocn_a_00733


.. _SSS+11:

**Shackman, A. J., Salomons, T. V., Slagter, H. A., Fox, A. S., Winter, J. J. & Davidson, R. J.** (2011). The integration of negative affect, pain and cognitive control in the cingulate cortex. *Nature Reviews Neuroscience*, *12*, 154–167.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1038/nrn2994

  URL: http://www.ncbi.nlm.nih.gov/pubmed/21331082


.. _Shi10:

**Shiffrin, R.** (2010). Perspectives on Modeling in Cognitive Science. *Topics in Cognitive Science*, *2*, 736–750.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1111/j.1756-8765.2010.01092.x


.. _SCR+13:

**Smith, D. V., Clithero, J. A., Rorden, C. & Karnath, H.** (2013). Decoding the anatomical network of spatial attention. *Proceedings of the National Academy of Sciences*, *110*, 1518-1523.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1073/pnas.1210126110


.. _SFK+12:

**Sobhani, M., Fox, G. R., Kaplan, J. & Aziz-Zadeh, L.** (2012). Interpersonal liking modulates motor-related neural regions. *PloS one*, *7*, e46809.
  DOI: http://dx.doi.org/10.1371/journal.pone.0046809


.. _SS09:

**Spacek, M. & Swindale, N.** (2009). Python in Neuroscience. *The Neuromorphic Engineer*.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.2417/1200907.1682


.. _ST12:

**Stelzer, J., Chen, Y. & Turner, R.** (2012). Statistical inference and multiple testing correction in classification-based multi-voxel pattern analysis (MVPA): Random permutations and cluster size control. *NeuroImage*, *65*, 69-82.
  Keywords: :keyword:`pymvpa-reference`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2012.09.063


.. _SPB+13:

**Strnad, L., Peelen, M. V., Bedny, M. & Caramazza, A.** (2013). Multivoxel Pattern Analysis Reveals Auditory Motion Information in MT+ of Both Congenitally Blind and Sighted Individuals. *PloS one*, *8*, e63198.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1371/journal.pone.0063198


.. _SET+09:

**Sun, D., van Erp, T. G., Thompson, P. M., Bearden, C. E., Daley, M., Kushan, L., Hardt, M. E., Nuechterlein, K. H., Toga, A. W. & Cannon, T. D.** (2009). Elucidating an MRI-Based Neuroanatomic Biomarker for Psychosis: Classification Analysis Using Probabilistic Brain Atlas and Machine Learning Algorithms. *Biological Psychiatry*, *66*, 1055–1060.
  *First published study employing PyMVPA for MRI-based analysis of Psychosis.*

  Keywords: :keyword:`pymvpa`, :keyword:`psychosis`, :keyword:`MRI`

  DOI: http://dx.doi.org/10.1016/j.biopsych.2009.07.019


.. _TRL09:

**Trautmann, E., Ray, L. & Lever, J.** (2009). Development of an autonomous robot for ground penetrating radar surveys of polar ice. The 2009 IEEE/RSJ International Conference on Intelligent Robots and Systems (IROS), 1685–1690.
  *Study using PyMVPA to perform immobilization detection to improve navigation
  reliability of an autonomous robot.*

  DOI: http://dx.doi.org/10.1109/IROS.2009.5354290


.. _vdL+12:

**Van der Laan, L. N., De Ridder, D. T., Viergever, M. A. & Smeets, P. A.** (2012). Appearance matters: neural correlates of food choice and packaging aesthetics. *PloS one*, *7*, e41738.
  DOI: http://dx.doi.org/10.1371/journal.pone.0041738


.. _Vap95:

**Vapnik, V.** (1995). The Nature of Statistical Learning Theory. Springer: New York.
  Keywords: :keyword:`support vector machine`, :keyword:`SVM`


.. _VS06:

**Varma, S. & Simon, R.** (2006). Bias in error estimation when using cross-validation for model selection. *BMC Bioinformatics*, *7*, 91.
  *Demonstration of overfitting and introducing the bias in the error estimation
  using cross-validation on entire dataset for performing model selection.*

  Keywords: :keyword:`statistical learning`, :keyword:`model selection`, :keyword:`error estimation`, :keyword:`hypothesis testing`

  DOI: http://dx.doi.org/10.1186/1471-2105-7-91

  URL: http://www.ncbi.nlm.nih.gov/pubmed/16504092


.. _VCL11:

**Vickery, T. J., Chun, M. M. & Lee, D.** (2011). Ubiquity and Specificity of Reinforcement Signals throughout the Human Brain . *Neuron *, *72*, 166-177.
  DOI: http://dx.doi.org/10.1016/j.neuron.2011.08.011

  URL: http://www.sciencedirect.com/science/article/pii/S089662731100732X


.. _VCG12:

**Viswanathan, S., Cieslak, M. & Grafton, S. T.** (2012). On the geometric structure of fMRI searchlight-based information maps. *arXiv preprint arXiv:1210.6317*.

.. _WLM+14:

**Wang, Q., Luo, S., Monterosso, J., Zhang, J., Fang, X., Dong, Q. & Xue, G.** (2014). Distributed Value Representation in the Medial Prefrontal Cortex during Intertemporal Choices. *Journal of Neuroscience*, *34*, 7522-7530.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1523/jneurosci.0351-14.2014

  URL: http://dx.doi.org/10.1523/JNEUROSCI.0351-14.2014


.. _WCW+07:

**Wang, Z., Childress, A. R., Wang, J. & Detre, J. A.** (2007). Support vector machine learning-based fMRI data group analysis. *NeuroImage*, *36*, 1139–51.
  Keywords: :keyword:`support vector machine`, :keyword:`SVM`, :keyword:`group analysis`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2007.03.072


.. _WHA14:

**Watson, D. M., Hartley, T. & Andrews, T. J.** (2014). Patterns of response to visual scenes are linked to the low-level properties of the image. *NeuroImage*, *99*, 402-410.
  Keywords: :keyword:`pymvpa`

  DOI: http://dx.doi.org/10.1016/j.neuroimage.2014.05.045

  URL: http://dx.doi.org/10.1016/j.neuroimage.2014.05.045


.. _WTB+10:

**Woolgar, A., Thompson, R., Bor, D. & Duncan, J.** (2010). Multi-voxel coding of stimuli, rules, and responses in human frontoparietal cortex. *NeuroImage*.
  DOI: http://dx.doi.org/10.1016/j.neuroimage.2010.04.035

  URL: http://www.ncbi.nlm.nih.gov/pubmed/20406690


.. _Wri09:

**Wright, D.** (2009). Ten Statisticians and Their Impacts for Psychologists. *Perspectives on Psychological Science*, *4*, 587–597.
  *Historical excurse into the life of 10 prominent statisticians of XXth century
  and their scientific contributions.*

  Keywords: :keyword:`statistics`, :keyword:`hypothesis testing`

  DOI: http://dx.doi.org/10.1111/j.1745-6924.2009.01167.x


.. _XLR2012:

**Xu, H., Lorbert, A., Ramadge, P. J., Guntupalli, J. S. & Haxby, J. V.** (2012). Regularized hyperalignment of multi-set fMRI data. Proceedings of the 2012 IEEE Signal Processing Workshop.

.. _ZH05:

**Zou, H. & Hastie, T.** (2005). Regularization and variable selection via the elastic net. *Journal of the Royal Statistical Society Series B*, *67*, 301–320.
  Keywords: :keyword:`feature selection`, :keyword:`statistical learning`

  URL: http://www-stat.stanford.edu/%7Ehastie/Papers/B67.2%20(2005)%20301-320%20Zou%20%26%20Hastie.pdf




